@@ -42,4 +42,4 @@ class ModelFitterReport(ModelFitterBootstrap):
         f.reportBootstrap()
         """
         self._checkBootstrap()
-        print(self.bootstrapResult)
+        self._logger.activity(self.bootstrapResult)
